@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 module YARD::CodeObjects
   # An ExtraFileObject represents an extra documentation file (README or other
   # file). It is not strictly a CodeObject (does not inherit from `Base`) although
@@ -5,9 +6,10 @@ module YARD::CodeObjects
   # compatible with most CodeObject interfaces.
   class ExtraFileObject
     attr_accessor :filename
-    attr_accessor :attributes
+    attr_writer :attributes
     attr_accessor :name
-    attr_accessor :contents
+    # @since 0.8.3
+    attr_reader :locale
 
     # Creates a new extra file object.
     # @param [String] filename the location on disk of the file
@@ -17,21 +19,47 @@ module YARD::CodeObjects
       self.filename = filename
       self.name = File.basename(filename).gsub(/\.[^.]+$/, '')
       self.attributes = SymbolHash.new(false)
-      parse_contents(contents || File.read(@filename))
+      @original_contents = contents
+      @parsed = false
+      @locale = nil
+      ensure_parsed
     end
 
     alias path name
 
+    def attributes
+      ensure_parsed
+      @attributes
+    end
+
     def title
       attributes[:title] || name
     end
 
+    def contents
+      ensure_parsed
+      @contents
+    end
+
+    def contents=(contents)
+      @original_contents = contents
+      @parsed = false
+    end
+
+    # @param [String] locale the locale name to be translated.
+    # @return [void]
+    # @since 0.8.3
+    def locale=(locale)
+      @locale = locale
+      @parsed = false
+    end
+
     def inspect
       "#<yardoc #{type} #{filename} attrs=#{attributes.inspect}>"
     end
     alias to_s inspect
 
-    def type; 'extra_file' end
+    def type; :extra_file end
 
     def ==(other)
       return false unless self.class === other
@@ -43,10 +71,17 @@ module YARD::CodeObjects
 
     private
 
+    def ensure_parsed
+      return if @parsed
+      @parsed = true
+      @contents = parse_contents(@original_contents || File.read(@filename))
+    end
+
     # @param [String] data the file contents
     def parse_contents(data)
       retried = false
       cut_index = 0
+      data = translate(data)
       data = data.split("\n")
       data.each_with_index do |line, index|
         case line
@@ -59,13 +94,15 @@ module YARD::CodeObjects
           end
         when /^\s*#\s*@(\S+)\s*(.+?)\s*$/
           attributes[$1] = $2
+        when /^\s*<!--\s*$/, /^\s*-->\s*$/
+          # Ignore HTML comments
         else
           cut_index = index
           break
         end
       end
       data = data[cut_index..-1] if cut_index > 0
-      self.contents = data.join("\n")
+      contents = data.join("\n")
 
       if contents.respond_to?(:force_encoding) && attributes[:encoding]
         begin
@@ -74,16 +111,25 @@ module YARD::CodeObjects
           log.warn "Invalid encoding `#{attributes[:encoding]}' in #{filename}"
         end
       end
+      contents
     rescue ArgumentError => e
-      if retried && e.message =~ /invalid byte sequence/
+      raise unless e.message =~ /invalid byte sequence/
+
+      if retried
         # This should never happen.
         log.warn "Could not read #{filename}, #{e.message}. You probably want to set `--charset`."
-        self.contents = ''
-        return
+        return ''
+      else
+        data.force_encoding('binary') if data.respond_to?(:force_encoding)
+        retried = true
+        retry
       end
-      data.force_encoding('binary') if data.respond_to?(:force_encoding)
-      retried = true
-      retry
+    end
+
+    def translate(data)
+      return data if locale.nil?
+      text = YARD::I18n::Text.new(data, :have_header => true)
+      text.translate(YARD::Registry.locale(locale))
     end
   end
-end
\ No newline at end of file
+end
