@@ -1,9 +1,14 @@
-require 'rubygems/user_interaction'
-require 'rubygems/doc_manager'
+# frozen_string_literal: true
+begin
+  require 'rubygems/user_interaction'
+  require 'rubygems/doc_manager'
+rescue LoadError
+  nil # noop
+end
 
 class Gem::DocManager
   def self.load_yardoc
-    require File.dirname(__FILE__) + '/../../yard'
+    require File.expand_path(File.join(File.dirname(__FILE__), *%w(.. .. yard)))
   end
 
   def run_yardoc(*args)
@@ -11,19 +16,19 @@ class Gem::DocManager
     args << '--backtrace' if Gem.configuration.backtrace
     unless File.file?(File.join(@spec.full_gem_path, '.yardopts'))
       args << @spec.require_paths
-      if @spec.extra_rdoc_files.size > 0
+      unless @spec.extra_rdoc_files.empty?
         args << '-'
         args += @spec.extra_rdoc_files
       end
     end
-    args = args.flatten.map {|arg| arg.to_s }
+    args = args.flatten.map(&:to_s)
 
     old_pwd = Dir.pwd
     Dir.chdir(@spec.full_gem_path)
     YARD::CLI::Yardoc.run(*args)
   rescue Errno::EACCES => e
     dirname = File.dirname e.message.split("-")[1].strip
-    raise Gem::FilePermissionError.new(dirname)
+    raise Gem::FilePermissionError, dirname
   rescue => ex
     alert_error "While generating documentation for #{@spec.full_name}"
     ui.errs.puts "... MESSAGE:   #{ex}"
@@ -34,10 +39,10 @@ class Gem::DocManager
     Dir.chdir(old_pwd)
   end
 
-  undef setup_rdoc
+  begin undef setup_rdoc; rescue NameError; nil end
   def setup_rdoc
-    if File.exist?(@doc_dir) && !File.writable?(@doc_dir) then
-      raise Gem::FilePermissionError.new(@doc_dir)
+    if File.exist?(@doc_dir) && !File.writable?(@doc_dir)
+      raise Gem::FilePermissionError, @doc_dir
     end
 
     FileUtils.mkdir_p @doc_dir unless File.exist?(@doc_dir)
@@ -64,8 +69,11 @@ class Gem::DocManager
     say "Building YARD (yri) index for #{@spec.full_name}..."
     run_yardoc '-c', '-n'
   end
-  alias install_ri_yard_orig install_ri
-  alias install_ri install_ri_yard
+
+  begin
+    alias install_ri_yard_orig install_ri
+    alias install_ri install_ri_yard
+  rescue NameError; nil end
 
   def install_rdoc_yard
     if @spec.has_rdoc?
@@ -74,6 +82,9 @@ class Gem::DocManager
       install_yardoc
     end
   end
-  alias install_rdoc_yard_orig install_rdoc
-  alias install_rdoc install_rdoc_yard
+
+  begin
+    alias install_rdoc_yard_orig install_rdoc
+    alias install_rdoc install_rdoc_yard
+  rescue NameError; nil end
 end
