@@ -1,13 +1,13 @@
-require File.join(File.dirname(__FILE__), "..", "spec_helper")
+# frozen_string_literal: true
 require 'stringio'
 
 include Handlers
 
 def undoc_error(code)
-  lambda { StubbedSourceParser.parse_string(code) }.should raise_error(Parser::UndocumentableError)
+  expect { StubbedSourceParser.parse_string(code) }.to raise_error(Parser::UndocumentableError)
 end
 
-def with_parser(parser_type, &block)
+def with_parser(parser_type)
   tmp = StubbedSourceParser.parser_type
   StubbedSourceParser.parser_type = parser_type
   yield
@@ -16,7 +16,7 @@ end
 
 class StubbedProcessor < Processor
   def process(statements)
-    statements.each_with_index do |stmt, index|
+    statements.each_with_index do |stmt, _index|
       find_handlers(stmt).each do |handler|
         handler.new(self, stmt).process
       end
